window.Gleam.initSearch([{"doc":"sparkleplug","title":"sparkleplug","content":"# sparkleplug - A Sparkplug library for Gleam\r\n\r\n[![Package Version](https://img.shields.io/hexpm/v/sparkleplug)](https://hex.pm/packages/sparkleplug)\r\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/sparkleplug/)\r\n\r\n## Overview\r\nThis library provides some representations of [Sparkplug B](https://sparkplug.eclipse.org/specification/) objects within the\r\nGleam type system, as well as some basic utilities for interacting with them.\r\nBoth Erlang and Javascript targets are supported.\r\n\r\n```sh\r\ngleam add sparkleplug@1\r\n```\r\n```gleam\r\nimport sparkleplug\r\n\r\npub fn main() {\r\n  // A simple JSON-encoded Sparkplug B payload.\r\n  let payload_string =\r\n    &quot;{\r\n      \\&quot;timestamp\\&quot;: 1486144502122,\r\n      \\&quot;metrics\\&quot;: [\r\n        {\r\n          \\&quot;name\\&quot;: \\&quot;My Metric\\&quot;,\r\n          \\&quot;alias\\&quot;: 1,\r\n          \\&quot;timestamp\\&quot;: 1479123452194,\r\n          \\&quot;dataType\\&quot;: \\&quot;String\\&quot;,\r\n          \\&quot;value\\&quot;: \\&quot;Test\\&quot;\r\n        }\r\n      ],\r\n      \\&quot;seq\\&quot;: 2\r\n    }&quot;\r\n\r\n  // This gives you a decoded Payload type to use in your Gleam program.\r\n  let assert Ok(decoded_payload) = sparkleplug.string_to_sparkplug_payload(payload_string)\r\n  ...\r\n}\r\n```\r\n\r\nFurther documentation can be found at &lt;https://hexdocs.pm/sparkleplug&gt;.\r\n\r\n## Development\r\n\r\n```sh\r\ngleam run   # Run the project\r\ngleam test  # Run the tests\r\n```\r\n## Limitations\r\nThere is currently very limited support for Sparkplug data sets, templates,\r\nproperty sets, and metric extensions.\r\n","url":"index.html"},{"doc":"sparkleplug/sparkplug_b/payload/dataset","title":"DataSet","content":"pub type DataSet {\n  DataSet(\n    num_of_columns: Option(Int),\n    columns: List(String),\n    types: List(Int),\n    rows: List(Row),\n  )\n}\n\nDataSet(\n  num_of_columns: Option(Int),\n  columns: List(String),\n  types: List(Int),\n  rows: List(Row),\n)\n\n\nSynonyms:\nsparkleplug/sparkplug_b/payload/dataset.DataSet\nsparkleplug/sparkplug_b/payload/dataset DataSet","url":"sparkleplug/sparkplug_b/payload/dataset.html#DataSet"},{"doc":"sparkleplug/sparkplug_b/payload/dataset","title":"DataSetValue","content":"pub type DataSetValue {\n  DataSetValue(value: Option(Value))\n}\n\nDataSetValue(value: Option(Value))\n\n\nSynonyms:\nsparkleplug/sparkplug_b/payload/dataset.DataSetValue\nsparkleplug/sparkplug_b/payload/dataset DataSetValue","url":"sparkleplug/sparkplug_b/payload/dataset.html#DataSetValue"},{"doc":"sparkleplug/sparkplug_b/payload/dataset","title":"DataSetValueExtension","content":"pub type DataSetValueExtension =\n  String\n\n\nSynonyms:\nsparkleplug/sparkplug_b/payload/dataset.DataSetValueExtension\nsparkleplug/sparkplug_b/payload/dataset DataSetValueExtension","url":"sparkleplug/sparkplug_b/payload/dataset.html#DataSetValueExtension"},{"doc":"sparkleplug/sparkplug_b/payload/dataset","title":"Row","content":"pub type Row {\n  Row(elements: List(DataSetValue))\n}\n\nRow(elements: List(DataSetValue))\n\n\nSynonyms:\nsparkleplug/sparkplug_b/payload/dataset.Row\nsparkleplug/sparkplug_b/payload/dataset Row","url":"sparkleplug/sparkplug_b/payload/dataset.html#Row"},{"doc":"sparkleplug/sparkplug_b/payload/dataset","title":"Value","content":"pub type Value {\n  IntValue(Int)\n  LongValue(Int)\n  FloatValue(Float)\n  DoubleValue(Float)\n  BooleanValue(Bool)\n  StringValue(String)\n  ExtensionValue(DataSetValueExtension)\n}\n\nIntValue(Int)\n\n\nLongValue(Int)\n\n\nFloatValue(Float)\n\n\nDoubleValue(Float)\n\n\nBooleanValue(Bool)\n\n\nStringValue(String)\n\n\nExtensionValue(DataSetValueExtension)\n\n\nSynonyms:\nsparkleplug/sparkplug_b/payload/dataset.Value\nsparkleplug/sparkplug_b/payload/dataset Value","url":"sparkleplug/sparkplug_b/payload/dataset.html#Value"},{"doc":"sparkleplug/sparkplug_b/payload/dataset","title":"sparkleplug/sparkplug_b/payload/dataset","content":"","url":"sparkleplug/sparkplug_b/payload/dataset.html"},{"doc":"sparkleplug/sparkplug_b/payload/datatype","title":"DataType","content":"pub type DataType {\n  Unknown\n  Int8\n  Int16\n  Int32\n  Int64\n  UInt8\n  UInt16\n  UInt32\n  UInt64\n  Float\n  Double\n  Boolean\n  String\n  DateTime\n  Text\n  UUID\n  DataSet\n  Bytes\n  File\n  Template\n  PropertySet\n  PropertySetList\n  Int8Array\n  Int16Array\n  Int32Array\n  Int64Array\n  UInt8Array\n  UInt16Array\n  UInt32Array\n  UInt64Array\n  FloatArray\n  DoubleArray\n  BooleanArray\n  StringArray\n  DateTimeArray\n}\n\nUnknown\n\n\nInt8\n\n\nInt16\n\n\nInt32\n\n\nInt64\n\n\nUInt8\n\n\nUInt16\n\n\nUInt32\n\n\nUInt64\n\n\nFloat\n\n\nDouble\n\n\nBoolean\n\n\nString\n\n\nDateTime\n\n\nText\n\n\nUUID\n\n\nDataSet\n\n\nBytes\n\n\nFile\n\n\nTemplate\n\n\nPropertySet\n\n\nPropertySetList\n\n\nInt8Array\n\n\nInt16Array\n\n\nInt32Array\n\n\nInt64Array\n\n\nUInt8Array\n\n\nUInt16Array\n\n\nUInt32Array\n\n\nUInt64Array\n\n\nFloatArray\n\n\nDoubleArray\n\n\nBooleanArray\n\n\nStringArray\n\n\nDateTimeArray\n\n\nSynonyms:\nsparkleplug/sparkplug_b/payload/datatype.DataType\nsparkleplug/sparkplug_b/payload/datatype DataType","url":"sparkleplug/sparkplug_b/payload/datatype.html#DataType"},{"doc":"sparkleplug/sparkplug_b/payload/datatype","title":"DataTypeParseError","content":"pub type DataTypeParseError {\n  DataTypeParseError(message: String)\n}\n\nDataTypeParseError(message: String)\n\n\nSynonyms:\nsparkleplug/sparkplug_b/payload/datatype.DataTypeParseError\nsparkleplug/sparkplug_b/payload/datatype DataTypeParseError","url":"sparkleplug/sparkplug_b/payload/datatype.html#DataTypeParseError"},{"doc":"sparkleplug/sparkplug_b/payload/datatype","title":"DataTypeValue","content":"pub type DataTypeValue {\n  DataTypeValue(Option(Int))\n}\n\nDataTypeValue(Option(Int))\n\n\nSynonyms:\nsparkleplug/sparkplug_b/payload/datatype.DataTypeValue\nsparkleplug/sparkplug_b/payload/datatype DataTypeValue","url":"sparkleplug/sparkplug_b/payload/datatype.html#DataTypeValue"},{"doc":"sparkleplug/sparkplug_b/payload/datatype","title":"decode_datatype_value","content":"pub fn decode_datatype_value(\n  data: Dynamic,\n) -&gt; Result(DataTypeValue, List(DecodeError))\n\nSynonyms:\nsparkleplug/sparkplug_b/payload/datatype.decode_datatype_value\nsparkleplug/sparkplug_b/payload/datatype decode_datatype_value","url":"sparkleplug/sparkplug_b/payload/datatype.html#decode_datatype_value"},{"doc":"sparkleplug/sparkplug_b/payload/datatype","title":"from_int","content":"pub fn from_int(int: Int) -&gt; Result(DataType, DataTypeParseError)\n\nSynonyms:\nsparkleplug/sparkplug_b/payload/datatype.from_int\nsparkleplug/sparkplug_b/payload/datatype from_int","url":"sparkleplug/sparkplug_b/payload/datatype.html#from_int"},{"doc":"sparkleplug/sparkplug_b/payload/datatype","title":"from_string","content":"pub fn from_string(\n  string: String,\n) -&gt; Result(DataType, DataTypeParseError)\n\nSynonyms:\nsparkleplug/sparkplug_b/payload/datatype.from_string\nsparkleplug/sparkplug_b/payload/datatype from_string","url":"sparkleplug/sparkplug_b/payload/datatype.html#from_string"},{"doc":"sparkleplug/sparkplug_b/payload/datatype","title":"to_int","content":"pub fn to_int(data_type: DataType) -&gt; Int\n\nSynonyms:\nsparkleplug/sparkplug_b/payload/datatype.to_int\nsparkleplug/sparkplug_b/payload/datatype to_int","url":"sparkleplug/sparkplug_b/payload/datatype.html#to_int"},{"doc":"sparkleplug/sparkplug_b/payload/datatype","title":"to_string","content":"pub fn to_string(data_type: DataType) -&gt; String\n\nSynonyms:\nsparkleplug/sparkplug_b/payload/datatype.to_string\nsparkleplug/sparkplug_b/payload/datatype to_string","url":"sparkleplug/sparkplug_b/payload/datatype.html#to_string"},{"doc":"sparkleplug/sparkplug_b/payload/datatype","title":"sparkleplug/sparkplug_b/payload/datatype","content":"","url":"sparkleplug/sparkplug_b/payload/datatype.html"},{"doc":"sparkleplug/sparkplug_b/payload/propertyset","title":"PropertySet","content":"pub type PropertySet {\n  PropertySet(keys: List(String), values: List(PropertyValue))\n}\n\nPropertySet(keys: List(String), values: List(PropertyValue))\n\n\nSynonyms:\nsparkleplug/sparkplug_b/payload/propertyset.PropertySet\nsparkleplug/sparkplug_b/payload/propertyset PropertySet","url":"sparkleplug/sparkplug_b/payload/propertyset.html#PropertySet"},{"doc":"sparkleplug/sparkplug_b/payload/propertyset","title":"PropertySetList","content":"pub type PropertySetList {\n  PropertySetList(propertyset: List(PropertySet))\n}\n\nPropertySetList(propertyset: List(PropertySet))\n\n\nSynonyms:\nsparkleplug/sparkplug_b/payload/propertyset.PropertySetList\nsparkleplug/sparkplug_b/payload/propertyset PropertySetList","url":"sparkleplug/sparkplug_b/payload/propertyset.html#PropertySetList"},{"doc":"sparkleplug/sparkplug_b/payload/propertyset","title":"PropertyValue","content":"pub type PropertyValue {\n  PropertyValue(\n    type_: Option(Int),\n    is_null: Option(Bool),\n    value: Option(Value),\n  )\n}\n\nPropertyValue(\n  type_: Option(Int),\n  is_null: Option(Bool),\n  value: Option(Value),\n)\n\n\nSynonyms:\nsparkleplug/sparkplug_b/payload/propertyset.PropertyValue\nsparkleplug/sparkplug_b/payload/propertyset PropertyValue","url":"sparkleplug/sparkplug_b/payload/propertyset.html#PropertyValue"},{"doc":"sparkleplug/sparkplug_b/payload/propertyset","title":"PropertyValueExtension","content":"pub type PropertyValueExtension =\n  String\n\n\nSynonyms:\nsparkleplug/sparkplug_b/payload/propertyset.PropertyValueExtension\nsparkleplug/sparkplug_b/payload/propertyset PropertyValueExtension","url":"sparkleplug/sparkplug_b/payload/propertyset.html#PropertyValueExtension"},{"doc":"sparkleplug/sparkplug_b/payload/propertyset","title":"Value","content":"pub type Value {\n  IntValue(Int)\n  LongValue(Int)\n  FloatValue(Float)\n  DoubleValue(Float)\n  BooleanValue(Bool)\n  StringValue(String)\n  PropertysetValue(PropertySet)\n  PropertysetsValue(PropertySetList)\n  ExtensionValue(PropertyValueExtension)\n}\n\nIntValue(Int)\n\n\nLongValue(Int)\n\n\nFloatValue(Float)\n\n\nDoubleValue(Float)\n\n\nBooleanValue(Bool)\n\n\nStringValue(String)\n\n\nPropertysetValue(PropertySet)\n\n\nPropertysetsValue(PropertySetList)\n\n\nExtensionValue(PropertyValueExtension)\n\n\nSynonyms:\nsparkleplug/sparkplug_b/payload/propertyset.Value\nsparkleplug/sparkplug_b/payload/propertyset Value","url":"sparkleplug/sparkplug_b/payload/propertyset.html#Value"},{"doc":"sparkleplug/sparkplug_b/payload/propertyset","title":"sparkleplug/sparkplug_b/payload/propertyset","content":"","url":"sparkleplug/sparkplug_b/payload/propertyset.html"},{"doc":"sparkleplug/sparkplug_b/payload/metric","title":"Metric","content":"pub type Metric {\n  Metric(\n    name: Option(String),\n    alias: Option(Int),\n    timestamp: Option(Int),\n    datatype: Option(Int),\n    is_historical: Option(Bool),\n    is_transient: Option(Bool),\n    is_null: Option(Bool),\n    metadata: Option(String),\n    value: Option(Value),\n  )\n}\n\nMetric(\n  name: Option(String),\n  alias: Option(Int),\n  timestamp: Option(Int),\n  datatype: Option(Int),\n  is_historical: Option(Bool),\n  is_transient: Option(Bool),\n  is_null: Option(Bool),\n  metadata: Option(String),\n  value: Option(Value),\n)\n\n\nSynonyms:\nsparkleplug/sparkplug_b/payload/metric.Metric\nsparkleplug/sparkplug_b/payload/metric Metric","url":"sparkleplug/sparkplug_b/payload/metric.html#Metric"},{"doc":"sparkleplug/sparkplug_b/payload/metric","title":"MetricValueExtension","content":"pub type MetricValueExtension {\n  MetricValueExtension(value: String)\n}\n\nMetricValueExtension(value: String)\n\n\nSynonyms:\nsparkleplug/sparkplug_b/payload/metric.MetricValueExtension\nsparkleplug/sparkplug_b/payload/metric MetricValueExtension","url":"sparkleplug/sparkplug_b/payload/metric.html#MetricValueExtension"},{"doc":"sparkleplug/sparkplug_b/payload/metric","title":"Parameter","content":"pub type Parameter {\n  Parameter(\n    name: Option(String),\n    type_: Option(String),\n    value: Option(String),\n  )\n}\n\nParameter(\n  name: Option(String),\n  type_: Option(String),\n  value: Option(String),\n)\n\n\nSynonyms:\nsparkleplug/sparkplug_b/payload/metric.Parameter\nsparkleplug/sparkplug_b/payload/metric Parameter","url":"sparkleplug/sparkplug_b/payload/metric.html#Parameter"},{"doc":"sparkleplug/sparkplug_b/payload/metric","title":"Template","content":"pub type Template {\n  Template(\n    version: Option(String),\n    metrics: List(Metric),\n    parameters: List(Parameter),\n    template_ref: Option(String),\n    is_definition: Option(Bool),\n  )\n}\n\nTemplate(\n  version: Option(String),\n  metrics: List(Metric),\n  parameters: List(Parameter),\n  template_ref: Option(String),\n  is_definition: Option(Bool),\n)\n\n\nSynonyms:\nsparkleplug/sparkplug_b/payload/metric.Template\nsparkleplug/sparkplug_b/payload/metric Template","url":"sparkleplug/sparkplug_b/payload/metric.html#Template"},{"doc":"sparkleplug/sparkplug_b/payload/metric","title":"Value","content":"pub type Value {\n  IntValue(Int)\n  LongValue(Int)\n  FloatValue(Float)\n  DoubleValue(Float)\n  BooleanValue(Bool)\n  StringValue(String)\n  BytesValue(BitArray)\n  DatasetValue(DataSet)\n  TemplateValue(Template)\n  ExtensionValue(MetricValueExtension)\n  PropertySetValue(propertyset.PropertySet)\n  PropertySetListValue(propertyset.PropertySetList)\n}\n\nIntValue(Int)\n\n\nLongValue(Int)\n\n\nFloatValue(Float)\n\n\nDoubleValue(Float)\n\n\nBooleanValue(Bool)\n\n\nStringValue(String)\n\n\nBytesValue(BitArray)\n\n\nDatasetValue(DataSet)\n\n\nTemplateValue(Template)\n\n\nExtensionValue(MetricValueExtension)\n\n\nPropertySetValue(propertyset.PropertySet)\n\n\nPropertySetListValue(propertyset.PropertySetList)\n\n\nSynonyms:\nsparkleplug/sparkplug_b/payload/metric.Value\nsparkleplug/sparkplug_b/payload/metric Value","url":"sparkleplug/sparkplug_b/payload/metric.html#Value"},{"doc":"sparkleplug/sparkplug_b/payload/metric","title":"sparkleplug/sparkplug_b/payload/metric","content":"","url":"sparkleplug/sparkplug_b/payload/metric.html"},{"doc":"sparkleplug/sparkplug_b/payload/payload","title":"Payload","content":"pub type Payload {\n  Payload(\n    timestamp: Option(Int),\n    metrics: List(Metric),\n    seq: Option(Int),\n    uuid: Option(String),\n    body: Option(String),\n  )\n}\n\nPayload(\n  timestamp: Option(Int),\n  metrics: List(Metric),\n  seq: Option(Int),\n  uuid: Option(String),\n  body: Option(String),\n)\n\n\nSynonyms:\nsparkleplug/sparkplug_b/payload/payload.Payload\nsparkleplug/sparkplug_b/payload/payload Payload","url":"sparkleplug/sparkplug_b/payload/payload.html#Payload"},{"doc":"sparkleplug/sparkplug_b/payload/payload","title":"sparkleplug/sparkplug_b/payload/payload","content":"","url":"sparkleplug/sparkplug_b/payload/payload.html"},{"doc":"sparkleplug","title":"bit_array_to_sparkplug_payload","content":"pub fn bit_array_to_sparkplug_payload(\n  payload_bit_array: BitArray,\n) -&gt; Result(Payload, String)\n Attempts to convert a bit array representation of a Sparkplug B payload into a Payload type.\n\n Returns an error if the bit array doesn&#39;t hold a valid representation.\nSynonyms:\nsparkleplug.bit_array_to_sparkplug_payload\nsparkleplug bit_array_to_sparkplug_payload","url":"sparkleplug.html#bit_array_to_sparkplug_payload"},{"doc":"sparkleplug","title":"metric_to_json_string","content":"pub fn metric_to_json_string(metric: Metric) -&gt; String\n Serialise a Metric into a JSON string.\nSynonyms:\nsparkleplug.metric_to_json_string\nsparkleplug metric_to_json_string","url":"sparkleplug.html#metric_to_json_string"},{"doc":"sparkleplug","title":"sparkplug_payload_to_json_string","content":"pub fn sparkplug_payload_to_json_string(\n  payload: Payload,\n) -&gt; String\n Serialise a Payload into a JSON string.\nSynonyms:\nsparkleplug.sparkplug_payload_to_json_string\nsparkleplug sparkplug_payload_to_json_string","url":"sparkleplug.html#sparkplug_payload_to_json_string"},{"doc":"sparkleplug","title":"string_to_metric","content":"pub fn string_to_metric(\n  metric_string: String,\n) -&gt; Result(Metric, DecodeError)\n Attempts to convert a string representation of a Sparkplug B metric into a Metric type.\n\n Returns an error if the string doesn&#39;t hold a valid representation.\nSynonyms:\nsparkleplug.string_to_metric\nsparkleplug string_to_metric","url":"sparkleplug.html#string_to_metric"},{"doc":"sparkleplug","title":"string_to_sparkplug_payload","content":"pub fn string_to_sparkplug_payload(\n  payload_string: String,\n) -&gt; Result(Payload, String)\n Attempts to convert a string representation of a Sparkplug B payload into a Payload type.\n\n Returns an error if the string doesn&#39;t hold a valid representation.\nSynonyms:\nsparkleplug.string_to_sparkplug_payload\nsparkleplug string_to_sparkplug_payload","url":"sparkleplug.html#string_to_sparkplug_payload"},{"doc":"sparkleplug","title":"sparkleplug","content":"","url":"sparkleplug.html"},{"doc":"sparkleplug/sparkplug_b/device_message_types","title":"DeviceMessageType","content":"pub type DeviceMessageType {\n  DBIRTH\n  DDEATH\n  DDATA\n  DCMD\n}\n\nDBIRTH\n\n\nDDEATH\n\n\nDDATA\n\n\nDCMD\n\n\nSynonyms:\nsparkleplug/sparkplug_b/device_message_types.DeviceMessageType\nsparkleplug/sparkplug_b/device_message_types DeviceMessageType","url":"sparkleplug/sparkplug_b/device_message_types.html#DeviceMessageType"},{"doc":"sparkleplug/sparkplug_b/device_message_types","title":"DeviceMessageTypeParseError","content":"pub type DeviceMessageTypeParseError {\n  DeviceMessageTypeParseError(message: String)\n}\n\nDeviceMessageTypeParseError(message: String)\n\n\nSynonyms:\nsparkleplug/sparkplug_b/device_message_types.DeviceMessageTypeParseError\nsparkleplug/sparkplug_b/device_message_types DeviceMessageTypeParseError","url":"sparkleplug/sparkplug_b/device_message_types.html#DeviceMessageTypeParseError"},{"doc":"sparkleplug/sparkplug_b/device_message_types","title":"from_string","content":"pub fn from_string(\n  message_type_string: String,\n) -&gt; Result(DeviceMessageType, DeviceMessageTypeParseError)\n\nSynonyms:\nsparkleplug/sparkplug_b/device_message_types.from_string\nsparkleplug/sparkplug_b/device_message_types from_string","url":"sparkleplug/sparkplug_b/device_message_types.html#from_string"},{"doc":"sparkleplug/sparkplug_b/device_message_types","title":"to_string","content":"pub fn to_string(message_type: DeviceMessageType) -&gt; String\n\nSynonyms:\nsparkleplug/sparkplug_b/device_message_types.to_string\nsparkleplug/sparkplug_b/device_message_types to_string","url":"sparkleplug/sparkplug_b/device_message_types.html#to_string"},{"doc":"sparkleplug/sparkplug_b/device_message_types","title":"sparkleplug/sparkplug_b/device_message_types","content":"","url":"sparkleplug/sparkplug_b/device_message_types.html"},{"doc":"sparkleplug/sparkplug_b/node_message_types","title":"NodeMessageType","content":"pub type NodeMessageType {\n  NBIRTH\n  NDEATH\n  NDATA\n  NCMD\n}\n\nNBIRTH\n\n\nNDEATH\n\n\nNDATA\n\n\nNCMD\n\n\nSynonyms:\nsparkleplug/sparkplug_b/node_message_types.NodeMessageType\nsparkleplug/sparkplug_b/node_message_types NodeMessageType","url":"sparkleplug/sparkplug_b/node_message_types.html#NodeMessageType"},{"doc":"sparkleplug/sparkplug_b/node_message_types","title":"NodeMessageTypeParseError","content":"pub type NodeMessageTypeParseError {\n  NodeMessageTypeParseError(message: String)\n}\n\nNodeMessageTypeParseError(message: String)\n\n\nSynonyms:\nsparkleplug/sparkplug_b/node_message_types.NodeMessageTypeParseError\nsparkleplug/sparkplug_b/node_message_types NodeMessageTypeParseError","url":"sparkleplug/sparkplug_b/node_message_types.html#NodeMessageTypeParseError"},{"doc":"sparkleplug/sparkplug_b/node_message_types","title":"from_string","content":"pub fn from_string(\n  message_type_string: String,\n) -&gt; Result(NodeMessageType, NodeMessageTypeParseError)\n\nSynonyms:\nsparkleplug/sparkplug_b/node_message_types.from_string\nsparkleplug/sparkplug_b/node_message_types from_string","url":"sparkleplug/sparkplug_b/node_message_types.html#from_string"},{"doc":"sparkleplug/sparkplug_b/node_message_types","title":"to_string","content":"pub fn to_string(message_type: NodeMessageType) -&gt; String\n\nSynonyms:\nsparkleplug/sparkplug_b/node_message_types.to_string\nsparkleplug/sparkplug_b/node_message_types to_string","url":"sparkleplug/sparkplug_b/node_message_types.html#to_string"},{"doc":"sparkleplug/sparkplug_b/node_message_types","title":"sparkleplug/sparkplug_b/node_message_types","content":"","url":"sparkleplug/sparkplug_b/node_message_types.html"},{"doc":"sparkleplug/sparkplug_b/payload/metadata","title":"MetaData","content":"pub type MetaData {\n  MetaData(\n    is_multi_part: Option(Bool),\n    content_type: Option(String),\n    size: Option(Int),\n    seq: Option(Int),\n    file_name: Option(String),\n    file_type: Option(String),\n    md5: Option(String),\n    description: Option(String),\n  )\n}\n\nMetaData(\n  is_multi_part: Option(Bool),\n  content_type: Option(String),\n  size: Option(Int),\n  seq: Option(Int),\n  file_name: Option(String),\n  file_type: Option(String),\n  md5: Option(String),\n  description: Option(String),\n)\n\n\nSynonyms:\nsparkleplug/sparkplug_b/payload/metadata.MetaData\nsparkleplug/sparkplug_b/payload/metadata MetaData","url":"sparkleplug/sparkplug_b/payload/metadata.html#MetaData"},{"doc":"sparkleplug/sparkplug_b/payload/metadata","title":"sparkleplug/sparkplug_b/payload/metadata","content":"","url":"sparkleplug/sparkplug_b/payload/metadata.html"},{"doc":"sparkleplug/sparkplug_b/topic_namespace","title":"TopicNamespace","content":"pub type TopicNamespace {\n  SpAv10\n  SpBv10\n}\n\nSpAv10\n\n\nSpBv10\n\n\nSynonyms:\nsparkleplug/sparkplug_b/topic_namespace.TopicNamespace\nsparkleplug/sparkplug_b/topic_namespace TopicNamespace","url":"sparkleplug/sparkplug_b/topic_namespace.html#TopicNamespace"},{"doc":"sparkleplug/sparkplug_b/topic_namespace","title":"TopicNamespaceParseError","content":"pub type TopicNamespaceParseError {\n  TopicNamespaceParseError(message: String)\n}\n\nTopicNamespaceParseError(message: String)\n\n\nSynonyms:\nsparkleplug/sparkplug_b/topic_namespace.TopicNamespaceParseError\nsparkleplug/sparkplug_b/topic_namespace TopicNamespaceParseError","url":"sparkleplug/sparkplug_b/topic_namespace.html#TopicNamespaceParseError"},{"doc":"sparkleplug/sparkplug_b/topic_namespace","title":"from_string","content":"pub fn from_string(\n  namespace_string: String,\n) -&gt; Result(TopicNamespace, TopicNamespaceParseError)\n\nSynonyms:\nsparkleplug/sparkplug_b/topic_namespace.from_string\nsparkleplug/sparkplug_b/topic_namespace from_string","url":"sparkleplug/sparkplug_b/topic_namespace.html#from_string"},{"doc":"sparkleplug/sparkplug_b/topic_namespace","title":"to_string","content":"pub fn to_string(topic_namespace: TopicNamespace) -&gt; String\n\nSynonyms:\nsparkleplug/sparkplug_b/topic_namespace.to_string\nsparkleplug/sparkplug_b/topic_namespace to_string","url":"sparkleplug/sparkplug_b/topic_namespace.html#to_string"},{"doc":"sparkleplug/sparkplug_b/topic_namespace","title":"sparkleplug/sparkplug_b/topic_namespace","content":"","url":"sparkleplug/sparkplug_b/topic_namespace.html"},{"doc":"sparkleplug/sparkplug_b/topic_name","title":"TopicName","content":"pub type TopicName {\n  NodeMessage(\n    namespace: TopicNamespace,\n    group_id: String,\n    message_type: NodeMessageType,\n    node_id: String,\n  )\n  DeviceMessage(\n    namespace: TopicNamespace,\n    group_id: String,\n    message_type: DeviceMessageType,\n    node_id: String,\n    device_id: String,\n  )\n  StateMessage(scada_host_id: String)\n}\n\nNodeMessage(\n  namespace: TopicNamespace,\n  group_id: String,\n  message_type: NodeMessageType,\n  node_id: String,\n)\n\n\nDeviceMessage(\n  namespace: TopicNamespace,\n  group_id: String,\n  message_type: DeviceMessageType,\n  node_id: String,\n  device_id: String,\n)\n\n\nStateMessage(scada_host_id: String)\n\n\nSynonyms:\nsparkleplug/sparkplug_b/topic_name.TopicName\nsparkleplug/sparkplug_b/topic_name TopicName","url":"sparkleplug/sparkplug_b/topic_name.html#TopicName"},{"doc":"sparkleplug/sparkplug_b/topic_name","title":"TopicNameParseError","content":"pub type TopicNameParseError {\n  TopicNameParseError(message: String)\n}\n\nTopicNameParseError(message: String)\n\n\nSynonyms:\nsparkleplug/sparkplug_b/topic_name.TopicNameParseError\nsparkleplug/sparkplug_b/topic_name TopicNameParseError","url":"sparkleplug/sparkplug_b/topic_name.html#TopicNameParseError"},{"doc":"sparkleplug/sparkplug_b/topic_name","title":"from_string","content":"pub fn from_string(\n  topic_string: String,\n) -&gt; Result(TopicName, TopicNameParseError)\n\nSynonyms:\nsparkleplug/sparkplug_b/topic_name.from_string\nsparkleplug/sparkplug_b/topic_name from_string","url":"sparkleplug/sparkplug_b/topic_name.html#from_string"},{"doc":"sparkleplug/sparkplug_b/topic_name","title":"to_string","content":"pub fn to_string(topic_name: TopicName) -&gt; String\n\nSynonyms:\nsparkleplug/sparkplug_b/topic_name.to_string\nsparkleplug/sparkplug_b/topic_name to_string","url":"sparkleplug/sparkplug_b/topic_name.html#to_string"},{"doc":"sparkleplug/sparkplug_b/topic_name","title":"sparkleplug/sparkplug_b/topic_name","content":"","url":"sparkleplug/sparkplug_b/topic_name.html"}]);